==> chaosmesh-model-6.8.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/BlockDelaySpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class BlockDelaySpecFluent<A extends BlockDelaySpecFluent<A>> extends BaseFluent<A>{
  public BlockDelaySpecFluent() {
  }
  public BlockDelaySpecFluent(BlockDelaySpec instance) {
    instance = (instance != null ? instance : new BlockDelaySpec());

    if (instance != null) {
      this.withCorrelation(instance.getCorrelation());
      this.withJitter(instance.getJitter());
      this.withLatency(instance.getLatency());
      this.withCorrelation(instance.getCorrelation());
      this.withJitter(instance.getJitter());
      this.withLatency(instance.getLatency());
    }
  }
  private String correlation;
  private String jitter;
  private String latency;
  public String getCorrelation() {
    return this.correlation;
  }
  public A withCorrelation(String correlation) {
    this.correlation=correlation; return (A) this;
  }
  public boolean hasCorrelation() {
    return this.correlation != null;
  }
  public String getJitter() {
    return this.jitter;
  }
  public A withJitter(String jitter) {
    this.jitter=jitter; return (A) this;
  }
  public boolean hasJitter() {
    return this.jitter != null;
  }
  public String getLatency() {
    return this.latency;
  }
  public A withLatency(String latency) {
    this.latency=latency; return (A) this;
  }
  public boolean hasLatency() {
    return this.latency != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BlockDelaySpecFluent that = (BlockDelaySpecFluent) o;
    if (!java.util.Objects.equals(correlation, that.correlation)) return false;

    if (!java.util.Objects.equals(jitter, that.jitter)) return false;

    if (!java.util.Objects.equals(latency, that.latency)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(correlation,  jitter,  latency,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (correlation != null) { sb.append("correlation:"); sb.append(correlation + ","); }
    if (jitter != null) { sb.append("jitter:"); sb.append(jitter + ","); }
    if (latency != null) { sb.append("latency:"); sb.append(latency); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/BlockDelaySpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class BlockDelaySpecFluent<A extends BlockDelaySpecFluent<A>> extends BaseFluent<A>{
  public BlockDelaySpecFluent() {
  }
  
  public BlockDelaySpecFluent(BlockDelaySpec instance) {
    this.copyInstance(instance);
  }
  private String correlation;
  private String jitter;
  private String latency;
  
  protected void copyInstance(BlockDelaySpec instance) {
    instance = (instance != null ? instance : new BlockDelaySpec());
  
    if (instance != null) {
        this.withCorrelation(instance.getCorrelation());
        this.withJitter(instance.getJitter());
        this.withLatency(instance.getLatency());
        this.withCorrelation(instance.getCorrelation());
        this.withJitter(instance.getJitter());
        this.withLatency(instance.getLatency());
      }
  }
  
  public String getCorrelation() {
    return this.correlation;
  }
  
  public A withCorrelation(String correlation) {
    this.correlation=correlation; return (A) this;
  }
  
  public boolean hasCorrelation() {
    return this.correlation != null;
  }
  
  public String getJitter() {
    return this.jitter;
  }
  
  public A withJitter(String jitter) {
    this.jitter=jitter; return (A) this;
  }
  
  public boolean hasJitter() {
    return this.jitter != null;
  }
  
  public String getLatency() {
    return this.latency;
  }
  
  public A withLatency(String latency) {
    this.latency=latency; return (A) this;
  }
  
  public boolean hasLatency() {
    return this.latency != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BlockDelaySpecFluent that = (BlockDelaySpecFluent) o;
    if (!java.util.Objects.equals(correlation, that.correlation)) return false;
  
    if (!java.util.Objects.equals(jitter, that.jitter)) return false;
  
    if (!java.util.Objects.equals(latency, that.latency)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(correlation,  jitter,  latency,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (correlation != null) { sb.append("correlation:"); sb.append(correlation + ","); }
    if (jitter != null) { sb.append("jitter:"); sb.append(jitter + ","); }
    if (latency != null) { sb.append("latency:"); sb.append(latency); }
    sb.append("}");
    return sb.toString();
  }
  

}
